Skip to contents

Specify mappings from levels in the data to displayed marker stroke colours.

Usage

chart_data_stroke(x, values, ...)

Arguments

x

an ms_chart object.

values

character(num of series): a set of colour values to map data values to. It is a named vector, the values will be matched based on the names. If it contains only one colour, this colour will be associated to all existing series.

...

arguments passed to S3 methods.

Value

An ms_chart object.

Examples

my_scatter <- ms_scatterchart(data = iris, x = "Sepal.Length",
  y = "Sepal.Width",  group = "Species")
my_scatter <- chart_data_fill(my_scatter,
  values = c(virginica = "#6FA2FF", versicolor = "#FF6161", setosa = "#81FF5B") )
my_scatter <- chart_data_stroke(my_scatter,
  values = c(virginica = "black", versicolor = "black", setosa = "black") )