Learn R Programming

mschart (version 0.5.1)

chart_data_fill: Modify fill colour

Description

Specify mappings from levels in the data to displayed fill colours.

Usage

chart_data_fill(x, values, update_stroke = TRUE)

Value

An ms_chart object.

Arguments

x

an ms_chart object.

values

character(num of series|1): a set of colour values to map data values to. It is a named vector, the values will be matched based on the names. If it contains only one colour, this colour will be associated to all existing series.

update_stroke

if TRUE (the default), the series stroke colour is also updated to values, so that the filled shape and its border match. Series whose stroke was set to "transparent" (for example by the ms_areachart() and ms_piechart() constructors) are left untouched to preserve that deliberate "no border" default. Set to FALSE to keep the current stroke colours untouched and manage them independently via chart_data_stroke().

See Also

Other Series customization functions: chart_data_line_style(), chart_data_line_width(), chart_data_size(), chart_data_smooth(), chart_data_stroke(), chart_data_symbol(), chart_labels_text()

Examples

Run this code
my_scatter <- ms_scatterchart(data = iris, x = "Sepal.Length",
  y = "Sepal.Width",  group = "Species")
my_scatter <- chart_data_fill(my_scatter,
  values = c(virginica = "#6FA2FF", versicolor = "#FF6161", setosa = "#81FF5B") )

Run the code above in your browser using DataLab